export default defineEventHandler((event) => {
  let username = req.session.user as string || '1234'
  let docker = createDockerFactory(username)
  let container = await docker.checkContainer('logwire_backend_helper.' + username + '.node')
  if (!container) {
    // 不存在容器，则说明用户还没初始化
    res.sendStatus(200)
    return
  }
  let info = await container.inspect()
  if (info.State.Running) {
    // 正在运行，则认为正常
    res.sendStatus(200)
  } else {
    LogUtil.print(username, `[progress] [[1;34mInfo[m] 服务器异常关闭，正在重启...... \n`)
    await docker.startContainer({ container })
    // 依次打开 nginx, 后端服务，vscode-web
    try {
      await docker.execContainerCommand({ container, cmd: 'lsof -i:80' })
    } catch (err) {
      try {
        await docker.execContainerCommand({ container, cmd: 'nginx' })
        LogUtil.print(username, `[progress] [[1;34mInfo[m] Nginx 重启成功...... \n`)
      } catch (err) {
        res.status(500).send(err)
      }
    }
    try {
      await docker.execContainerCommand({ container, cmd: 'lsof -i:8000' })
    } catch (err) {
      try {
        docker.execContainerCommand({ container, cmd: 'code-server --bind-addr 127.0.0.1:8000 --auth none' })
        LogUtil.print(username, `[progress] [[1;34mInfo[m] Vscode 重启成功...... \n`)
      } catch (err) {
        res.status(500).send(err)
      }
    }
    try {
      await docker.execContainerCommand({ container, cmd: 'pm2 delete backend' })
      await docker.execContainerCommand({ container, cmd: 'pm2 delete gateway' })
    } catch (err) {
    }

    await docker.execContainerCommand({ container, cmd: 'pm2 start --name gateway --no-autorestart java -- -Xms128m -Xmx128m -XX:+UseG1GC --add-opens java.base/sun.util.locale.provider=ALL-UNNAMED -jar logwire-gateway-starter.jar', dir: '/var/logwire-backend/build-output/gateway', quiet: true })
    await docker.execContainerCommand({ container, cmd: `pm2 start --name backend --no-autorestart java -- -Xms128m -Xmx128m -XX:+UseG1GC -DVALIDATE_XML_ENABLED=false --add-opens java.base/sun.util.locale.provider=ALL-UNNAMED -jar logwire-backend-starter.jar`, dir: '/var/logwire-backend/build-output/backend', quiet: true })
    LogUtil.print(username, `[progress] [[1;34mInfo[m] 服务重启成功...... \n`)
    res.sendStatus(200)
  }
})