import path from 'path'
import fs from 'fs'
import lodash from 'lodash'
import { Telnet } from 'telnet-client'

export function getUserConfig (username: string, config: string) {
  let jsonPath = path.resolve('./server/data/' + username + '.json')
  try {
    let jsonStr = fs.readFileSync(jsonPath, { encoding: 'utf-8' })
    let json = JSON.parse(jsonStr) || {}
    return lodash.get(json, config)
  } catch (err: any) {
    console.log(err)
  }
}

// 在目标服务器上，获取 node 可用的端口
export async function getAvailableNodePort (ip: string, startPort = 30000) {
  const tryPortAvailable = async function (port: number): Promise<number> {
    let telnet = new Telnet()
    const params = {
      host: ip,
      port: port,
      negotiationMandatory: false,
      timeout: 1500
    }
    try {
      await telnet.connect(params)
      telnet.end()
      return tryPortAvailable(port + 1)
    } catch (err) {
      return port
    }
  }
  return tryPortAvailable(startPort)
}

export function getUserAllConfigs (username: string): Record<string, string> {
  let jsonPath = path.resolve('./server/data/' + username + '.json')
  let jsonStr = fs.readFileSync(jsonPath, { encoding: 'utf-8' })
  let json = JSON.parse(jsonStr) || {}
  return json
}